@@ -6,7 +6,7 @@
  * forth in the LICENSE file which can be found at the top level of
  * the sendmail distribution.
  *
- *	$Id: sm_os_freebsd.h,v 1.9 2001/06/27 21:46:48 gshapiro Exp $
+ *	$Id: sm_os_freebsd.h,v 1.10 2002/03/10 22:41:03 gshapiro Exp $
  */
 
 /*
@@ -31,7 +31,11 @@
 #endif
 
 #ifndef SM_CONF_SHM
-# define SM_CONF_SHM	1
+# ifdef __sparc64__
+#  define SM_CONF_SHM	0
+# else /* __sparc64__ */
+#  define SM_CONF_SHM	1
+# endif /* __sparc64__ */
 #endif /* SM_CONF_SHM */
 #ifndef SM_CONF_SEM
 # define SM_CONF_SEM	1
